@@ -6,7 +6,7 @@ import sys
 import logging
 from logging import handlers
 from functools import wraps
-
+from textwrap import shorten
 
 DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S"
 DATEFORMAT_DEV = "%H:%M:%S"
@@ -103,6 +103,7 @@ class CustomFormatter(logging.Formatter):
     """ Custom Formatter does these 2 things:
     1. Overrides 'funcName' with the value of 'func_name_override', if it exists.
     2. Overrides 'filename' with the value of 'file_name_override', if it exists.
+    3. Shortens 'funcName' and 'filename' so to not cause issues with the formatting.
     """
 
     def format(self, record):
@@ -110,12 +111,21 @@ class CustomFormatter(logging.Formatter):
             record.funcName = record.func_name_override
         if hasattr(record, 'file_name_override'):
             record.filename = record.file_name_override
+        if len(record.levelname) >= 9:
+            record.levelname = record.levelname[:9 - 3] + '...'
+        if len(record.threadName) >= 14:
+            record.threadName = record.threadName[:14 - 3] + '...'
+        if len(record.name) >= 35:
+            record.name = record.name[:35 - 3] + '...'
+        if len(record.funcName) >= 35:
+            record.funcName = record.funcName[:35 - 3] + '...'
+
         return super().format(record)
 
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^9}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
@@ -124,7 +134,7 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 def _stdout_handler():
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^9}|{threadName:^14}|{lineno:^7}| {name:<35}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
